@@ -5,12 +5,12 @@ def active_tab(tab, sub_tab=None):
 		import functools
 
 		@functools.wraps(func)
-		def wrapper(*args, **kwargs):
+		def wrapper(request, *args, **kwargs):
 			request.nav = request.nav if hasattr(request, "nav") else {}
 			request.nav["tab"] = tab
 			if sub_tab is not None:
 				request.nav["sub_tab"] = sub_tab
-			return func(*args, **kwargs)
+			return func(request, *args, **kwargs)
 		return wrapper
 
 	return outer_wrapper
